==> katana-0.1.0b.tar.gz: katana-0.1.0b/src/util/logging.h <==
/*
  File: logging.h
  Author: James Oakley
  Copyright (C): 2010 Dartmouth College
  License: Katana is free software: you may redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 2 of the
    License, or (at your option) any later version. Regardless of
    which version is chose, the following stipulation also applies:
    
    Any redistribution must include copyright notice attribution to
    Dartmouth College as well as the Warranty Disclaimer below, as well as
    this list of conditions in any related documentation and, if feasible,
    on the redistributed software; Any redistribution must include the
    acknowledgment, “This product includes software developed by Dartmouth
    College,” in any related documentation and, if feasible, in the
    redistributed software; and The names “Dartmouth” and “Dartmouth
    College” may not be used to endorse or promote products derived from
    this software.  

                             WARRANTY DISCLAIMER

    PLEASE BE ADVISED THAT THERE IS NO WARRANTY PROVIDED WITH THIS
    SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
    OTHERWISE STATED IN WRITING, DARTMOUTH COLLEGE, ANY OTHER COPYRIGHT
    HOLDERS, AND/OR OTHER PARTIES PROVIDING OR DISTRIBUTING THE SOFTWARE,
    DO SO ON AN "AS IS" BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER
    EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
    PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
    SOFTWARE FALLS UPON THE USER OF THE SOFTWARE. SHOULD THE SOFTWARE
    PROVE DEFECTIVE, YOU (AS THE USER OR REDISTRIBUTOR) ASSUME ALL COSTS
    OF ALL NECESSARY SERVICING, REPAIR OR CORRECTIONS.

    IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
    WILL DARTMOUTH COLLEGE OR ANY OTHER COPYRIGHT HOLDER, OR ANY OTHER
    PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED
    ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL,
    INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR
    INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF
    DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
    THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
    PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
    POSSIBILITY OF SUCH DAMAGES.

    The complete text of the license may be found in the file COPYING
    which should have been distributed with this software. The GNU
    General Public License may be obtained at
    http://www.gnu.org/licenses/gpl.html

  Project: Katana
  Date: February 2010
  Description: Interface for logging information, errors, etc
*/

#ifndef logging_h
#define logging_h

typedef enum
{
  ELL_DISABLE=0,//exists for the purpose of something lower than all log levels, should never be used in a call to logprintf
  ELL_ERR,
  ELL_WARN,
  ELL_INFO_V1,
  ELL_INFO_V2,
  ELL_INFO_V3, //higher numbers are less important
  ELL_INFO_V4,
  ELL_CNT,
} E_LOG_LEVEL;

typedef enum
{
  ELS_MISC=0,
  ELS_DWARFTYPES,
  ELS_CODEDIFF,
  ELS_TYPEDIFF,
  ELS_DWARF_FRAME,
  ELS_HOTPATCH,
  ELS_SOURCETREE,
  ELS_SYMBOL,
  ELS_RELOCATION,
  ELS_PATCHAPPLY,
  ELS_LINKMAP,
  ELS_SAFETY,
  ELS_PATCHWRITE,
  ELS_PATH,
  ELS_ELFWRITE,
  ELS_CNT
} E_LOG_SOURCE;//describes what subsystem the message came from

int logprintf(E_LOG_LEVEL lvl,E_LOG_SOURCE src,char* fmt,...);

//all messages at this level or more important than this level (see the ordering in
//E_LOG_LEVEL definition) will be logged. Others will be dropped
void setMasterLogLevel(E_LOG_LEVEL lvl);

void enableLogSource(E_LOG_SOURCE src,E_LOG_LEVEL lvl);
void disableLogSource(E_LOG_SOURCE src);

void loggingDefaults();
#endif

==> katana-0.3.0b.tar.gz: katana-0.3.0b/src/util/logging.h <==
/*
  File: logging.h
  Author: James Oakley
  Copyright (C): 2010 Dartmouth College
  License: Katana is free software: you may redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 2 of the
    License, or (at your option) any later version. Regardless of
    which version is chose, the following stipulation also applies:
    
    Any redistribution must include copyright notice attribution to
    Dartmouth College as well as the Warranty Disclaimer below, as well as
    this list of conditions in any related documentation and, if feasible,
    on the redistributed software; Any redistribution must include the
    acknowledgment, “This product includes software developed by Dartmouth
    College,” in any related documentation and, if feasible, in the
    redistributed software; and The names “Dartmouth” and “Dartmouth
    College” may not be used to endorse or promote products derived from
    this software.  

                             WARRANTY DISCLAIMER

    PLEASE BE ADVISED THAT THERE IS NO WARRANTY PROVIDED WITH THIS
    SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
    OTHERWISE STATED IN WRITING, DARTMOUTH COLLEGE, ANY OTHER COPYRIGHT
    HOLDERS, AND/OR OTHER PARTIES PROVIDING OR DISTRIBUTING THE SOFTWARE,
    DO SO ON AN "AS IS" BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER
    EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
    PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
    SOFTWARE FALLS UPON THE USER OF THE SOFTWARE. SHOULD THE SOFTWARE
    PROVE DEFECTIVE, YOU (AS THE USER OR REDISTRIBUTOR) ASSUME ALL COSTS
    OF ALL NECESSARY SERVICING, REPAIR OR CORRECTIONS.

    IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
    WILL DARTMOUTH COLLEGE OR ANY OTHER COPYRIGHT HOLDER, OR ANY OTHER
    PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED
    ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL,
    INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR
    INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF
    DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
    THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
    PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
    POSSIBILITY OF SUCH DAMAGES.

    The complete text of the license may be found in the file COPYING
    which should have been distributed with this software. The GNU
    General Public License may be obtained at
    http://www.gnu.org/licenses/gpl.html

  Project: Katana
  Date: February 2010
  Description: Interface for logging information, errors, etc
*/

#ifndef logging_h
#define logging_h

typedef enum
{
  ELL_DISABLE=0,//exists for the purpose of something lower than all
                //log levels, should never be used in a call to
                //logprintf
  ELL_ERR,
  ELL_WARN,
  ELL_INFO_V1,
  ELL_INFO_V2,
  ELL_INFO_V3, //higher numbers are less important
  ELL_INFO_V4,
  ELL_CNT,
} E_LOG_LEVEL;

typedef enum
{
  ELS_MISC=0,
  ELS_DWARFTYPES,
  ELS_CODEDIFF,
  ELS_TYPEDIFF,
  ELS_DWARF_FRAME,
  ELS_HOTPATCH,
  ELS_SOURCETREE,
  ELS_SYMBOL,
  ELS_RELOCATION,
  ELS_PATCHAPPLY,
  ELS_LINKMAP,
  ELS_SAFETY,
  ELS_PATCHWRITE,
  ELS_PATH,
  ELS_ELFWRITE,
  ELS_VERSION,
  ELS_DWARFWRITE,
  ELS_CONFIG,
  ELS_LEB,
  ELS_SHELL,
  ELS_DWARFSCRIPT,
  ELS_DWARF_BUILD,
  ELS_VM,
  ELS_CLEANUP,
  ELS_CNT
} E_LOG_SOURCE;//describes what subsystem the message came from

int logprintf(E_LOG_LEVEL lvl,E_LOG_SOURCE src,const char* fmt,...);

//all messages at this level or more important than this level (see the ordering in
//E_LOG_LEVEL definition) will be logged. Others will be dropped
void setMasterLogLevel(E_LOG_LEVEL lvl);

void enableLogSource(E_LOG_SOURCE src,E_LOG_LEVEL lvl);
void disableLogSource(E_LOG_SOURCE src);

void loggingDefaults();
#endif
